@@ -36,10 +36,14 @@
 #include <QDesktopWidget>
 #include <QGSettings/QGSettings>
 #include <QtDBus/QtDBus>
+#include <QStyleOption>
 #include "common/ukuisettings.h"
 #include "iukuipanel.h"
 #include "ukuipanelglobals.h"
-#include "highlight-effect.h"
+#include "contextmenu.h"
+#include <KF5/KScreen/kscreen/config.h>
+#include <KF5/KScreen/kscreen/getconfigoperation.h>
+
 
 class QMenu;
 class Plugin;
@@ -50,7 +54,6 @@ class Settings;
 class PluginInfo;
 }
 class UKUIPanelLayout;
-class ConfigPanelDialog;
 
 class PanelPluginsModel;
 class WindowNotifier;
@@ -81,16 +84,13 @@ class UKUI_PANEL_API UKUIPanel : public QFrame, public IUKUIPanel
 {
     Q_OBJECT
 
-    Q_PROPERTY(QString position READ qssPosition)
 
     Q_CLASSINFO("D-Bus Interface", "org.ukui.panel.settings")
-    // for configuration dialog
-    friend class ConfigPanelWidget;
-    friend class ConfigPluginsWidget;
-    friend class ConfigPanelDialog;
     friend class PanelPluginsModel;
 
 public:
+    void configWatch(KScreen::ConfigOperation *op);
+    QRect m_primaryScreenGeometry;
     /**
      * @brief Stores how the panel should be aligned. Obviously, this applies
      * only if the panel does not occupy 100 % of the available space. If the
@@ -126,7 +126,7 @@ public:
      * @brief Returns the name of this panel which is also used as identifier
      * in the config file.
      */
-    QString name() { return mConfigGroup; }
+    QString name() { return m_configGroup; }
 
     /**
      * @brief Reads all the necessary settings from mSettings and stores them
@@ -143,10 +143,10 @@ public:
      * @param plugin The plugin whose menu options will be included in the
      * context menu.
      */
-    void showPopupMenu(Plugin *plugin = 0);
+    void showPopupMenu();
 
     // IUKUIPanel overrides ........
-    IUKUIPanel::Position position() const override { return mPosition; }
+    IUKUIPanel::Position position() const override { return m_position; }
     QRect globalGeometry() const override;
     /**
      * @brief calculatePopupWindowPos 计算任务栏弹窗的位置
@@ -169,32 +169,6 @@ public:
      */
     Plugin *findPlugin(const IUKUIPanelPlugin *iPlugin) const;
 
-    // For QSS properties ..................
-    /**
-     * @brief Returns the position as string
-     *
-     * \sa positionToStr().
-     */
-    QString qssPosition() const;
-
-    /**
-     * @brief Checks if this UKUIPanel can be placed at a given position
-     * on the screen with the given screenNum. The condition for doing so
-     * is that the panel is not located between two screens.
-     *
-     * For example, if position is PositionRight, there should be no screen to
-     * the right of the given screen. That means that there should be no
-     * screen whose left border has a higher x-coordinate than the x-coordinate
-     * of the right border of the given screen. This method iterates over all
-     * screens and checks these conditions.
-     * @param screenNum screen index as it is used by QDesktopWidget methods
-     * @param position position where the panel should be placed
-     * @return true if this panel can be placed at the given position on the
-     * given screen.
-     *
-     * \sa findAvailableScreen(), mScreenNum, mActualScreenNum.
-     */
-    static bool canPlacedOn(int screenNum, UKUIPanel::Position position);
     /**
      * @brief Returns a string representation of the given position. This
      * string is human-readable and can be used in config files.
@@ -221,23 +195,18 @@ public:
 
 
     // Settings
-    int iconSize() const override { return mIconSize; } //!< Implement IUKUIPanel::iconSize().
-    int lineCount() const override { return mLineCount; } //!< Implement IUKUIPanel::lineCount().
-    int panelSize() const override{ return mPanelSize; }
-    int length() const { return mLength; }
-    bool lengthInPercents() const { return mLengthInPercents; }
-    UKUIPanel::Alignment alignment() const { return mAlignment; }
-    int screenNum() const { return mScreenNum; }
-    QColor fontColor() const { return mFontColor; }
-    QColor backgroundColor() const { return mBackgroundColor; }
-    QString backgroundImage() const { return mBackgroundImage; }
-    int opacity() const { return mOpacity; }
-    int reserveSpace() const { return mReserveSpace; }
-    bool hidable() const { return mHidable; }
-    bool visibleMargin() const { return mVisibleMargin; }
-    int animationTime() const { return mAnimationTime; }
-    int showDelay() const { return mShowDelayTimer.interval(); }
-    QString iconTheme() const;
+    int iconSize() const override { return m_iconSize; } //!< Implement IUKUIPanel::iconSize().
+    int lineCount() const override { return m_lineCount; } //!< Implement IUKUIPanel::lineCount().
+    int panelSize() const override{ return m_panelSize; }
+    int length() const { return m_length; }
+    bool lengthInPercents() const { return m_lengthInPercents; }
+    UKUIPanel::Alignment alignment() const { return m_alignment; }
+    int screenNum() const { return m_screenNum; }
+    QColor fontColor() const { return m_fontColor; }
+    int reserveSpace() const { return m_reserveSpace; }
+    bool visibleMargin() const { return m_visibleMargin; }
+    int animationTime() const { return m_animationTime; }
+    int showDelay() const { return m_showDelayTimer.interval(); }
 
     /*!
      * \brief Checks if a given Plugin is running and has the
@@ -254,7 +223,7 @@ public:
      */
 //    void updateConfigDialog() const;
 
-public slots:
+public Q_SLOTS:
     /**
      * @brief Shows the QWidget and makes it visible on all desktops. This
      * method is NOT related to showPanel(), hidePanel() and hidePanelWork()
@@ -312,14 +281,10 @@ public slots:
     void setLength(int length, bool inPercents, bool save); //!< \sa setPanelSize()
     void setPosition(int screen, IUKUIPanel::Position position, bool save); //!< \sa setPanelSize()
     void setAlignment(UKUIPanel::Alignment value, bool save); //!< \sa setPanelSize()
-    void setFontColor(QColor color, bool save); //!< \sa setPanelSize()
-    void setBackgroundColor(QColor color, bool save); //!< \sa setPanelSize()
-    void setReserveSpace(bool reserveSpace, bool save); //!< \sa setPanelSize()
     void setHidable(bool hidable, bool save); //!< \sa setPanelSize()
     void setVisibleMargin(bool visibleMargin, bool save); //!< \sa setPanelSize()
     void setAnimationTime(int animationTime, bool save); //!< \sa setPanelSize()
     void setShowDelay(int showDelay, bool save); //!< \sa setPanelSize()
-    void setIconTheme(const QString& iconTheme);
 
     /**
      * @brief Saves the current configuration, i.e. writes the current
@@ -336,8 +301,9 @@ public slots:
      * where the desired position is possible.
      */
     void ensureVisible();
+    void primaryChangedSlot(int x, int y, int w, int h, int r);
 
-signals:
+Q_SIGNALS:
     /**
      * @brief This signal gets emitted whenever this panel receives a
      * QEvent::LayoutRequest, i.e. "Widget layout needs to be redone.".
@@ -399,10 +365,8 @@ protected:
     void mouseMoveEvent(QMouseEvent *event);
     void mouseReleaseEvent(QMouseEvent* event);
     void mousePressEvent(QMouseEvent *event);
-    void enterEvent(QEvent *event);
-    void leaveEvent(QEvent *event);
 
-public slots:
+public Q_SLOTS:
     /**
      * @brief Shows the ConfigPanelDialog and shows the "Config Panel"
      * page, i.e. calls showConfigPanelPage(). If the dialog does not
@@ -419,7 +383,7 @@ public slots:
      */
 //    void showConfigDialog();
 
-private slots:
+private Q_SLOTS:
     /**
      * @brief Shows the ConfigPanelDialog and shows the "Config Plugins"
      * page, i.e. calls showConfigPluginsPage(). If the dialog does not
@@ -440,11 +404,6 @@ private slots:
      * 2. UKUi::Application::themeChanged(), i.e. when the user changes
      * the theme.
      */
-    void systeMonitor();
-    void showDesktop();
-    void showTaskView();
-    void showNightModeButton();
-    void adjustPanel();
     void realign();
     /**
      * @brief Moves a plugin in PanelPluginsModel, i.e. calls
@@ -454,27 +413,19 @@ private slots:
      * @param plug
      */
     void pluginMoved(Plugin * plug);
-    /**
-     * @brief Removes this panel's entries from the config file and emits
-     * the deletedByUser signal.
-     * The "Remove Panel" button in the panel's contex menu will
-     * be connected to this slot, so this method will be called whenever
-     * the user clicks "Remove Panel".
-     */
-    void userRequestForDeletion();
-
 private:
-    int scale;
+    KScreen::ConfigPtr m_config;
+    bool m_isWaylandEnv;
     /**
      * @brief The UKUIPanelLayout of this panel. All the Plugins will be added
      * to the UI via this layout.
      */
-    UKUIPanelLayout* mLayout;
+    UKUIPanelLayout* m_layout;
     /**
      * @brief The UKUi::Settings instance as retrieved from
      * UKUIPanelApplication.
      */
-    UKUi::Settings *mSettings;
+    UKUi::Settings *m_settings;
     /**
      * @brief The background widget for the panel. This background widget will
      * have the background color or the background image if any of these is
@@ -486,30 +437,17 @@ private:
      * @brief The name of the panel which will also be used as an identifier
      * for config files.
      */
-    QString mConfigGroup;
+    QString m_configGroup;
     /**
      * @brief Pointer to the PanelPluginsModel which will store all the Plugins
      * that are loaded.
      */
-    QScopedPointer<PanelPluginsModel> mPlugins;
+    QScopedPointer<PanelPluginsModel> m_plugins;
     /**
      * @brief object for storing info if some standalone window is shown
      * (for preventing hide)
      */
-    QScopedPointer<WindowNotifier> mStandaloneWindows;
-
-    /**
-     * @brief Returns the screen index of a screen on which this panel could
-     * be placed at the given position. If possible, the current screen index
-     * is preserved. So, if the panel can be placed on the current screen, the
-     * index of that screen will be returned.
-     * @param position position at which the panel should be placed.
-     * @return The current screen index if the panel can be placed on the
-     * current screen or the screen index of a screen that it can be placed on.
-     *
-     * \sa canPlacedOn(), mScreenNum, mActualScreenNum.
-     */
-    int findAvailableScreen(UKUIPanel::Position position);
+    QScopedPointer<WindowNotifier> m_standaloneWindows;
     /**
      * @brief Update the window manager struts _NET_WM_PARTIAL_STRUT and
      * _NET_WM_STRUT for this widget. "The purpose of struts is to reserve
@@ -540,6 +478,8 @@ private:
      * \param animate flag if showing/hiding the panel should be animated.
      */
     void setPanelGeometry(bool animate = false);
+    QRect caculPanelGeometry(QRect primaryscreen);
+    void setPanelAnimation(QRect startrect, QRect endrect);
     /**
      * @brief Sets the contents margins of the panel according to its position
      * and hiddenness. All margins are zero for visible panels.
@@ -562,19 +502,19 @@ private:
      * \sa panelSize(), setPanelSize().
      */
     void styleAdjust();
-    int mPanelSize;
+    int m_panelSize;
     /**
      * @brief Stores the edge length of the panel icons in pixels.
      *
      * \sa IUKUIPanel::iconSize(), setIconSize().
      */
-    int mIconSize;
+    int m_iconSize;
     /**
      * @brief Stores the number of lines/rows of the panel.
      *
      * \sa IUKUIPanel::lineCount(), setLineCount().
      */
-    int mLineCount;
+    int m_lineCount;
 
     /**
      * @brief Stores the length of the panel, i.e. the width of a horizontal
@@ -583,7 +523,7 @@ private:
      *
      * \sa mLengthInPercents
      */
-    int mLength;
+    int m_length;
     /**
      * @brief Stores if mLength is stored in pixels or relative to the
      * screen size in percents. If true, the length is stored in percents,
@@ -591,7 +531,7 @@ private:
      *
      * \sa mLength
      */
-    bool mLengthInPercents;
+    bool m_lengthInPercents;
 
     /**
      * @brief Stores how this panel is aligned. The meaning of this value
@@ -599,12 +539,12 @@ private:
      *
      * \sa Alignment.
      */
-    Alignment mAlignment;
+    Alignment m_alignment;
 
     /**
      * @brief Stores the position where the panel is shown
      */
-    IUKUIPanel::Position mPosition;
+    IUKUIPanel::Position m_position;
     /**
      * @brief Returns the index of the screen on which this panel should be
      * shown. This is the user configured value which can differ from the
@@ -617,14 +557,14 @@ private:
      *
      * \sa mActualScreenNum, canPlacedOn(), findAvailableScreen().
      */
-    int mScreenNum;
+    int m_screenNum;
     /**
      * @brief screen that the panel is currently shown at (this could
      * differ from mScreenNum).
      *
      * \sa mScreenNum, canPlacedOn(), findAvailableScreen().
      */
-    int mActualScreenNum;
+    int m_actualScreenNum;
     /**
      * @brief QTimer for delayed saving of changed settings. In many cases,
      * instead of storing changes to disk immediately we start this timer.
@@ -641,19 +581,19 @@ private:
      *
      * \sa mVisibleMargin, mHidden, mHideTimer, showPanel(), hidePanel(), hidePanelWork()
      */
-    bool mHidable;
+    bool m_hidable;
     /**
      * @brief Stores if the hidable panel should have a visible margin.
      *
      * \sa mHidable, mHidden, mHideTimer, showPanel(), hidePanel(), hidePanelWork()
      */
-    bool mVisibleMargin;
+    bool m_visibleMargin;
     /**
      * @brief Stores if the panel is currently hidden.
      *
      * \sa mHidable, mVisibleMargin, mHideTimer, showPanel(), hidePanel(), hidePanelWork()
      */
-    bool mHidden;
+    bool m_hidden;
     /**
      * @brief QTimer for hiding the panel. When the cursor leaves the panel
      * area, this timer will be started. After this timer has timed out, the
@@ -661,23 +601,21 @@ private:
      *
      * \sa mHidable, mVisibleMargin, mHidden, showPanel(), hidePanel(), hidePanelWork()
      */
-    QTimer mHideTimer;
+    QTimer m_hideTimer;
     /**
      * @brief Stores the duration of auto-hide animation.
      *
      * \sa mHidden, mHideTimer, showPanel(), hidePanel(), hidePanelWork()
      */
-    int mAnimationTime;
+    int m_animationTime;
     /**
      * @brief The timer used for showing an auto-hiding panel wih delay.
      *
      * \sa showPanel()
      */
-    QTimer mShowDelayTimer;
+    QTimer m_showDelayTimer;
 
-    QColor mFontColor; //!< Font color that is used in the style sheet.
-    QColor mBackgroundColor; //!< Background color that is used in the style sheet.
-    QString mBackgroundImage; //!< Background image that is used in the style sheet.
+    QColor m_fontColor; //!< Font color that is used in the style sheet.
     /**
      * @brief Determines the opacity of the background color. The value
      * should be in the range from 0 to 100. This will not affect the opacity
@@ -691,61 +629,53 @@ private:
      *
      * \sa updateWmStrut()
      */
-    bool mReserveSpace;
+    bool m_reserveSpace;
 
     /**
      * @brief Pointer to the current ConfigPanelDialog if there is any. Make
      * sure to test this pointer for validity because it is lazily loaded.
      */
-//   QPointer<ConfigPanelDialog> mConfigDialog;
-    //ConfigPanelDialog  *mConfigDialog;
-    //QPointer<ConfigPanelWidget> mConfigWidget;
 
     /**
      * @brief The animation used for showing/hiding an auto-hiding panel.
      */
-    QPropertyAnimation *mAnimation;
+    QPropertyAnimation *m_animation;
 
     /**
      * @brief Flag for providing the configuration options in panel's context menu
      */
-    bool mLockPanel;
-    double transparency;
+    bool m_lockPanel;
+    double m_transparency;
 
     // settings should be kept private for security
-    UKUi::Settings *settings() const { return mSettings; }
+    UKUi::Settings *settings() const { return m_settings; }
 
     QDBusInterface *m_cloudInterface;
 
-    IUKUIPanel::Position oldpos;
+    IUKUIPanel::Position m_oldPos;
 
-    QMenu * menu;
+    QMenu * m_menu;
     QAction * m_lockAction;
-    /**
-     * @brief mDbusXrandInter
-     * 华为990双屏的dbus
-     */
-    QDBusInterface  *mDbusXrandInter;
-    QRect mcurrentScreenRect;
-    QString flag_hw990;
+    QRect m_currentScreenRect;
 
     IUKUIPanel::Position areaDivid(QPoint globalpos);
-    int movelock = -1;
+    int m_moveLock = -1;
 
     void connectToServer();
 
-private slots:
-    void panelReset();
+private Q_SLOTS:
     void keyChangedSlot(const QString &key);
     void priScreenChanged(int x, int y, int width, int height);
+    void setPanelHide(bool model);
 
 
 public:
-    QGSettings *gsettings;
-    QGSettings *transparency_gsettings;
-    QGSettings *scale_gsetting;
-    int scale_flag;
-    QTimer *time;
+    QGSettings *m_gsettings;
+    QStringList m_gsettingsKeys;
+    QGSettings *m_transparencyGsettings;
+    QTimer *m_time;
+
+    QDBusInterface *m_interface = nullptr;
 
 };
 
