@@ -21,14 +21,23 @@
 #include "lunarcalendaritem.h"
 #include "lunarcalendarwidget.h"
 #include "lunarcalendarinfo.h"
+#include "calendarcolor.h"
+
 #include "qpainter.h"
 #include "qevent.h"
 #include "qdatetime.h"
 #include "qdebug.h"
 #include <QGSettings>
 
-LunarCalendarItem::LunarCalendarItem(QWidget *parent) : QWidget(parent)
+//日历字号
+const int day_font_size = 18;
+const int lunar_font_size = 14;
+const int other_font_size = 12;
+
+LunarCalendarItem::LunarCalendarItem(QString font,QWidget *parent) : QWidget(parent),m_font(font)
 {
+    setProperty("useStyleWindowManager",false);
+    setAttribute(Qt::WA_TransparentForMouseEvents,true);
     hover = false;
     pressed = false;
 
@@ -45,84 +54,58 @@ LunarCalendarItem::LunarCalendarItem(QWidget *parent) : QWidget(parent)
     const QByteArray id("org.ukui.style");
     QGSettings * fontSetting = new QGSettings(id, QByteArray(), this);
     connect(fontSetting, &QGSettings::changed,[=](QString key) {
-        if(fontSetting->get("style-name").toString() == "ukui-default") {
-            weekColor = QColor(255, 255, 255);
-            currentTextColor = QColor(255, 255, 255);
-            otherTextColor = QColor(255, 255, 255,40);
-            otherLunarColor = QColor(255, 255, 255,40);
-            currentLunarColor = QColor(255, 255, 255,90);
-            lunarColor = QColor(255, 255, 255,90);
-        } else if(fontSetting->get("style-name").toString() == "ukui-light") {
-            weekColor = QColor(0, 0, 0);
-            currentTextColor = QColor(0, 0, 0);
-            otherTextColor = QColor(0,0,0,40);
-            otherLunarColor = QColor(0,0,0,40);
-            currentLunarColor = QColor(0,0,0,90);
-            lunarColor = QColor(0,0,0,90);
-        } else if(fontSetting->get("style-name").toString() == "ukui-dark") {
-            weekColor = QColor(255, 255, 255);
-            currentTextColor = QColor(255, 255, 255);
-            otherTextColor = QColor(255, 255, 255,40);
-            otherLunarColor = QColor(255, 255, 255,40);
-            currentLunarColor = QColor(255, 255, 255,90);
-            lunarColor = QColor(255, 255, 255,90);
+        if((key.compare("style-name") == 0) || (key.compare("theme-color") == 0)|| (key.compare("widget-theme-name")==0) ||
+            (key.compare("styleName") == 0) || (key.compare("themeColor") == 0)|| (key.compare("widgetThemeName")==0) ){
+            weekColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            otherTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherLunarColor.setAlphaF(0.35);
+            currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor.setAlphaF(0.45);
+            lunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            lunarColor.setAlphaF(0.35);
+            selectBgColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED);
+            //hoverBgColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED);
+            qreal mix = 0.2;
+            hoverBgColor = CalendarColor::CalendarColor::mixColor(CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED),mix);
+            this->update();
         }
     });
 
-    if(fontSetting->get("style-name").toString() == "ukui-light") {
-        weekColor = QColor(0, 0, 0);
-        currentTextColor = QColor(0, 0, 0);
-        otherTextColor = QColor(0,0,0,40);
-        otherLunarColor = QColor(0,0,0,40);
-        currentLunarColor = QColor(0,0,0,90);
-        lunarColor = QColor(0,0,0,90);
-    } else {
-        weekColor = QColor(255, 255, 255);
-        currentTextColor = QColor(255, 255, 255);
-        otherTextColor = QColor(255, 255, 255,40);
-        otherLunarColor = QColor(255, 255, 255,40);
-        currentLunarColor = QColor(255, 255, 255,90);
-        lunarColor = QColor(255, 255, 255,90);
-    }
-
-    borderColor = QColor(180, 180, 180);
-    superColor = QColor(255, 129, 6);
-
-    selectTextColor = QColor(255, 255, 255);
-    hoverTextColor = QColor(250, 250, 250);
-
-    selectLunarColor = QColor(255, 255, 255);
-    hoverLunarColor = QColor(250, 250, 250);
-
-    currentBgColor = QColor(255, 255, 255);
-    otherBgColor = QColor(240, 240, 240);
-    selectBgColor = QColor(55,144,250);
-    hoverBgColor = QColor(204, 183, 180);
+    weekColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+    currentTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+    otherTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+    otherLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+    otherLunarColor.setAlphaF(0.45);
+    currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+    lunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+    lunarColor.setAlphaF(0.35);
+    superColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::WORK);
+    selectTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED_TEXT);
+    hoverTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED_TEXT);
+    selectLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::WORK);
+    hoverLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::WORK);
+    selectBgColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED);
+    //hoverBgColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED);
+    qreal mix = 0.2;
+    hoverBgColor = CalendarColor::CalendarColor::mixColor(CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED),mix);
 }
 
-void LunarCalendarItem::enterEvent(QEvent *)
+void LunarCalendarItem::onEnter()
 {
-    hover = true;
-    this->update();
+        hover = true;
+        this->update();
 }
-
-void LunarCalendarItem::leaveEvent(QEvent *)
+void LunarCalendarItem::onLeave()
 {
-    hover = false;
-    this->update();
+        hover = false;
+        this->update();
 }
-
-void LunarCalendarItem::mousePressEvent(QMouseEvent *)
+void LunarCalendarItem::onSelected()
 {
-    pressed = true;
-    this->update();
     Q_EMIT clicked(date, dayType);
-}
-
-void LunarCalendarItem::mouseReleaseEvent(QMouseEvent *)
-{
-    pressed = false;
-    this->update();
+    update();
 }
 
 QString LunarCalendarItem::handleJsMap(QString year,QString month2day)
@@ -150,34 +133,64 @@ QString LunarCalendarItem::handleJsMap(QString year,QString month2day)
 
 void LunarCalendarItem::paintEvent(QPaintEvent *)
 {
-
     QDate dateNow = QDate::currentDate();
-
     //绘制准备工作,启用反锯齿
     QPainter painter(this);
     painter.setRenderHints(QPainter::Antialiasing | QPainter::TextAntialiasing);
-
     //绘制背景和边框
     drawBg(&painter);
-
     //对比当前的时间，画选中状态
     if(dateNow == date) {
          drawBgCurrent(&painter, selectBgColor);
-    }
-
-    //绘制悬停状态
-    if (hover) {
+         if(hover || select) {
+            drawBgHover(&painter, hoverBgColor);
+         }
+         //设置一个字的颜色
+         if (dayType == DayType_MonthCurrent) {
+            currentTextColor =CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED_TEXT);
+            currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::CLICKED_TEXT);
+            currentLunarColor.setAlphaF(0.45);
+         }
+    } else if (hover) {
+        //绘制悬停状态、绘制选中状态
         drawBgHover(&painter, hoverBgColor);
+        //设置一个字的颜色
+        if (dayType == DayType_MonthCurrent) {
+            currentTextColor =CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor.setAlphaF(0.45);
+        }else {
+            otherLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherLunarColor.setAlphaF(0.15);
+        }
+    } else if (select){
+        if(LunarCalendarWidget::getClickedDate() == date){
+            drawBgHover(&painter, hoverBgColor);
+        }
+        //设置一个字的颜色
+        if (dayType == DayType_MonthCurrent) {
+            currentTextColor =CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor.setAlphaF(0.45);
+        }else {
+            otherLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherLunarColor.setAlphaF(0.15);
+        }
+    }else {
+        if (dayType == DayType_MonthCurrent) {
+            currentTextColor =CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::TEXT);
+            currentLunarColor.setAlphaF(0.45);
+        }else {
+            otherLunarColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherTextColor = CalendarColor::CalendarColor::getThemeColor(CalendarColor::OTHER_TEXT);
+            otherLunarColor.setAlphaF(0.15);
+        }
     }
-
-    //绘制选中状态
-    if (select) {
-        drawBgHover(&painter, hoverBgColor);
-    }
-
     //绘制日期
     drawDay(&painter);
-
     //绘制农历信息
     drawLunar(&painter);
 }
@@ -192,10 +205,6 @@ void LunarCalendarItem::drawBg(QPainter *painter)
         bgColor = otherBgColor;
     }
 
-    //painter->setPen(borderColor);
-    //painter->setBrush(bgColor);
-    //painter->drawRect(rect());
-
     painter->restore();
 }
 
@@ -206,11 +215,8 @@ void LunarCalendarItem::drawBgCurrent(QPainter *painter, const QColor &color)
     painter->setBrush(color);
 
     QRect rect = this->rect();
-    painter->drawRoundedRect(rect,4,4);
-//    //根据设定绘制背景样式
-//    if (selectType == SelectType_Rect) {
-
-//    }
+    rect = QRect(rect.x()+1,rect.y()+1,rect.width()-2,rect.height()-2);
+    painter->drawRoundedRect(rect,6,6);
     painter->restore();
 }
 
@@ -218,12 +224,9 @@ void LunarCalendarItem::drawBgHover(QPainter *painter, const QColor &color)
 {
     painter->save();
     QRect rect = this->rect();
-    painter->setPen(QPen(QColor(55,143,250),2));
-    painter->drawRoundedRect(rect,4,4);
-//    //根据设定绘制背景样式
-//    if (selectType == SelectType_Rect) {
-
-//    }
+    rect = QRect(rect.x()+1,rect.y()+1,rect.width()-2,rect.height()-2);
+    painter->setPen(QPen(color,3));
+    painter->drawRoundedRect(rect,6,6);
     painter->restore();
 }
 
@@ -232,9 +235,8 @@ void LunarCalendarItem::drawDay(QPainter *painter)
     int width = this->width();
     int height = this->height();
     int side = qMin(width, height);
-
+//    qDebug() << width << height ;
     painter->save();
-
     //根据当前类型选择对应的颜色
     QColor color = currentTextColor;
     if (dayType == DayType_MonthPre || dayType == DayType_MonthNext) {
@@ -243,16 +245,10 @@ void LunarCalendarItem::drawDay(QPainter *painter)
         color = weekColor;
     }
 
-/*    if (select) {
-        color = selectTextColor;
-    } *//*else if (hover) {
-        color = hoverTextColor;
-    }*/
-
     painter->setPen(color);
 
-    QFont font;
-    font.setPixelSize(side * 0.3);
+    QFont font = m_font;
+    font.setPixelSize(day_font_size);
     //设置文字粗细
     font.setBold(true);
     painter->setFont(font);
@@ -260,34 +256,39 @@ void LunarCalendarItem::drawDay(QPainter *painter)
     QLocale locale = (QLocale::system().name() == "zh_CN" ? (QLocale::Chinese) : (QLocale::English));
     //代码复用率待优化
     if (showLunar) {
-        QRect dayRect = QRect(0, 0, width, height / 1.7);
-        painter->drawText(dayRect, Qt::AlignHCenter | Qt::AlignBottom, QString::number(date.day()));
+        QRect dayRect;
+        if(locale == QLocale::Chinese){
+             dayRect = QRect(0, 0, width, height / 1.7);
+        }
+        else {
+             dayRect = QRect(0, 0, width, height);
+        }
+        painter->drawText(dayRect, Qt::AlignHCenter | Qt::AlignVCenter, QString::number(date.day()));
         if (handleJsMap(date.toString("yyyy"),date.toString("MMdd")) == "2") {
             painter->setPen(Qt::NoPen);
             if(locale == QLocale::Chinese){
-                painter->setBrush(QColor(244,78,80));
+                painter->setBrush(CalendarColor::CalendarColor::getThemeColor(CalendarColor::HOLIDAY));
             }
             QRect dayRect1 = QRect(0, 0, width/3.5,height/3.5);
-            painter->drawRoundedRect(dayRect1,1,1);
-            font.setPixelSize(side / 5);
+            painter->drawRoundedRect(dayRect1,4,4);
+            font.setPixelSize(other_font_size);
             painter->setFont(font);
             painter->setPen(Qt::white);
             if(locale == QLocale::Chinese){
-                painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignBottom,"休");
+                painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignVCenter,"休");
             }
-
         } else if (handleJsMap(date.toString("yyyy"),date.toString("MMdd")) == "1") {
             painter->setPen(Qt::NoPen);
             if(locale == QLocale::Chinese){
-                painter->setBrush(QColor(251,170,42));
+                painter->setBrush(CalendarColor::CalendarColor::getThemeColor(CalendarColor::WORK));
             }
             QRect dayRect1 = QRect(0, 0, width/3.5,height/3.5);
-            painter->drawRoundedRect(dayRect1,1,1);
-            font.setPixelSize(side / 5);
+            painter->drawRoundedRect(dayRect1,4,4);
+            font.setPixelSize(other_font_size);
             painter->setFont(font);
             painter->setPen(Qt::white);
             if(locale == QLocale::Chinese){
-                painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignBottom,"班");
+                painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignVCenter,"班");
             }
         }
     }
@@ -297,22 +298,18 @@ void LunarCalendarItem::drawDay(QPainter *painter)
         painter->drawText(dayRect, Qt::AlignCenter, QString::number(date.day()));
         if (handleJsMap(date.toString("yyyy"),date.toString("MMdd")) == "2") {
             painter->setPen(Qt::NoPen);
-//            painter->setBrush(QColor(255,0,0));
             QRect dayRect1 = QRect(0, 0, width/3.5,height/3.5);
-            painter->drawRoundedRect(dayRect1,1,1);
-            font.setPixelSize(side / 5);
+            painter->drawRoundedRect(dayRect1,6,6);
+            font.setPixelSize(other_font_size);
             painter->setFont(font);
             painter->setPen(Qt::white);
-//            painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignBottom,"休");
         } else if (handleJsMap(date.toString("yyyy"),date.toString("MMdd")) == "1") {
             painter->setPen(Qt::NoPen);
-//            painter->setBrush(QColor(251,170,42));
             QRect dayRect1 = QRect(0, 0, width/3.5,height/3.5);
-            painter->drawRoundedRect(dayRect1,1,1);
-            font.setPixelSize(side / 5);
+            painter->drawRoundedRect(dayRect1,6,6);
+            font.setPixelSize(other_font_size);
             painter->setFont(font);
             painter->setPen(Qt::white);
-//            painter->drawText(dayRect1, Qt::AlignHCenter | Qt::AlignBottom,"班");
         }
     }
 
@@ -323,37 +320,9 @@ void LunarCalendarItem::drawLunar(QPainter *painter)
 {
     int width = this->width();
     int height = this->height();
-    int side = qMin(width, height);
-    int month;
-    int day;
-    QString strHoliday;
     QLocale locale = (QLocale::system().name() == "zh_CN" ? (QLocale::Chinese) : (QLocale::English));
-    qDebug()<<"LunarCalendarItem语言模式:"<<locale;
     painter->save();
-
-    if (!showLunar) {
-        //非农历
-//        int month = date.month();
-//        int day = date.day();
-//        LunarCalendarInfo *lun = LunarCalendarInfo::Instance();
-//        strHoliday = lun->getHoliday(month,day);
-////        delete lun;
-
-//        QColor color = currentLunarColor;
-//        if (dayType == DayType_MonthPre || dayType == DayType_MonthNext) {
-//            color = otherLunarColor;
-//        }
-//        painter->setPen(color);
-
-//        QFont font;
-//        font.setPixelSize(side * 0.27);
-//        painter->setFont(font);
-
-//        QRect lunarRect(0, height / 2, width, height / 2);
-//        painter->drawText(lunarRect, Qt::AlignCenter, strHoliday);
-    }
-    else {
-
+    if (showLunar){
         if(locale == QLocale::Chinese){
             QStringList listDayName;
             listDayName << "*" << "初一" << "初二" << "初三" << "初四" << "初五" << "初六" << "初七" << "初八" << "初九" << "初十"
@@ -362,38 +331,24 @@ void LunarCalendarItem::drawLunar(QPainter *painter)
 
             //判断当前农历文字是否节日,是节日且是当月则用农历节日颜色显示
             bool exist = (!listDayName.contains(lunar) && dayType != DayType_MonthPre && dayType != DayType_MonthNext);
-
             //根据当前类型选择对应的颜色
             QColor color = currentLunarColor;
             if (dayType == DayType_MonthPre || dayType == DayType_MonthNext) {
                 color = otherLunarColor;
             }
-
-        //    if (select) {
-        //        color = selectTextColor;
-        //    } /*else if (hover) {
-        //        color = hoverTextColor;
-        //    }*/ else if (exist) {
-        //        color = lunarColor;
-        //    }
-
             if (exist) {
-                   color = lunarColor;
+                color = currentLunarColor;
             }
-
             painter->setPen(color);
-
-            QFont font;
-            font.setPixelSize(side * 0.27);
+            QFont font = m_font;
+            font.setPixelSize(lunar_font_size);
             painter->setFont(font);
 
-            QRect lunarRect(0, height / 2, width, height / 2);
-            painter->drawText(lunarRect, Qt::AlignCenter, lunar);
+            QRect lunarRect(0, height / 2 + 4, width, height / 2);
+            painter->drawText(lunarRect, Qt::AlignTop|Qt::AlignHCenter, lunar);
             }
-            painter->restore();
         }
-
-
+    painter->restore();
 }
 
 
