@@ -50,12 +50,18 @@
 //#include "statusnotifieritemadaptor.h"
 #include "statusnotifierwatcher_interface.h"
 
+#include "xtestsender.h"
 
 //#define VISUAL_DEBUG
 
 #define SNI_WATCHER_SERVICE_NAME "org.kde.StatusNotifierWatcher"
 #define SNI_WATCHER_PATH "/StatusNotifierWatcher"
 
+#define UKUI_PANEL_DAEMON           "org.ukui.panel.daemon"
+#define UKUI_PANEL_DAEMON_PATH      "/convert/desktopwid"
+#define UKUI_PANEL_DAEMON_INTERFACE "org.ukui.panel.daemon"
+#define UKUI_PANEL_DAEMON_METHOD    "WIDToDesktop"
+
 static uint16_t s_embedSize = 32; //max size of window to embed. We no longer resize the embedded window as Chromium acts stupidly.
 static unsigned int XEMBED_VERSION = 0;
 
@@ -455,6 +461,21 @@ void SNIProxy::stackContainerWindow(const uint32_t stackMode) const
     xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_STACK_MODE, stackData);
 }
 
+QString SNIProxy::winidtoDesktopFileName(const WId& wid) const
+{
+    QDBusInterface iface(UKUI_PANEL_DAEMON,
+                         UKUI_PANEL_DAEMON_PATH,
+                         UKUI_PANEL_DAEMON_INTERFACE,
+                         QDBusConnection::sessionBus());
+    if(iface.isValid()) {
+        QDBusReply<QString> reply = iface.call(UKUI_PANEL_DAEMON_METHOD, int(wid));
+        QString processExeName = reply.value();
+        return processExeName;
+    } else {
+        return QString();
+    }
+}
+
 //____________properties__________
 
 QString SNIProxy::Category() const
@@ -471,6 +492,7 @@ QString SNIProxy::Id() const
         return QString::number(m_windowId);
     }
     return title;
+
 }
 
 KDbusImageVector SNIProxy::IconPixmap() const
@@ -494,19 +516,18 @@ QString SNIProxy::Title() const
     KWindowInfo window (m_windowId, NET::WMName,NET::WM2WindowClass);
     //根据应用的dekstop文件查找中文名
     QString toolTip;
-    ConvertDesktopToWinId *getDesktop = new ConvertDesktopToWinId();
-    QString appDesktopPath = getDesktop->tranIdToDesktop(window.win());
-    delete getDesktop;
+    QString appDesktopPath = winidtoDesktopFileName(window.win());
     if(QFile::exists(appDesktopPath)){
-        XdgDesktopFile xdg;
-        xdg.load(appDesktopPath);
-        toolTip = xdg.localizedValue("Name").toString();
-        if(!toolTip.isEmpty()){
-            return toolTip;
-        }
+       XdgDesktopFile xdg;
+       xdg.load(appDesktopPath);
+       toolTip = xdg.localizedValue("Name").toString();
+       if(!toolTip.isEmpty()){
+           return toolTip;
+       }
     }
     toolTip = QString(window.windowClassClass());
     return toolTip;
+
 }
 
 int SNIProxy::WindowId() const
@@ -550,6 +571,12 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     //note x,y are not actually where the mouse is, but the plasmoid
     //ideally we should make this match the plasmoid hit area
 
+    // ukui-panel (StatusNotifierHost) send scaled x, y. but pointer get from xcb is not.
+    // rescale input x, y to make sure the calculate work with highdpi sacle.
+    float scale = qApp->devicePixelRatio();
+    x = x * scale;
+    y = y * scale;
+
     qDebug() << "Received click" << mouseButton << "with passed x*y" << x << y;
     sendingClickEvent = true;
 
@@ -566,26 +593,23 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
     auto cookie = xcb_query_pointer(c, m_windowId);
     QScopedPointer<xcb_query_pointer_reply_t, QScopedPointerPodDeleter>
         pointer(xcb_query_pointer_reply(c, cookie, nullptr));
-    /*qCDebug(SNIPROXY) << "samescreen" << pointer->same_screen << endl
-	<< "root x*y" << pointer->root_x << pointer->root_y << endl
-	<< "win x*y" << pointer->win_x << pointer->win_y;*/
 
     //move our window so the mouse is within its geometry
     uint32_t configVals[2] = {0, 0};
     const QPoint clickPoint = calculateClickPoint();
     if (mouseButton >= XCB_BUTTON_INDEX_4) {
-	//scroll event, take pointer position
-	configVals[0] = pointer->root_x;
-	configVals[1] = pointer->root_y;
+        //scroll event, take pointer position
+        configVals[0] = pointer->root_x;
+        configVals[1] = pointer->root_y;
     } else {
-	if (pointer->root_x > x + clientGeom->width)
-	    configVals[0] = pointer->root_x - clientGeom->width + 1;
-	else
-	    configVals[0] = static_cast<uint32_t>(x - clickPoint.x());
-	if (pointer->root_y > y + clientGeom->height)
-	    configVals[1] = pointer->root_y - clientGeom->height + 1;
-	else
-	    configVals[1] = static_cast<uint32_t>(y - clickPoint.y());
+        if (pointer->root_x > x + clientGeom->width)
+            configVals[0] = pointer->root_x - clientGeom->width + 1;
+        else
+            configVals[0] = static_cast<uint32_t>(x - clickPoint.x() - clientGeom->width / 2);
+        if (pointer->root_y > y + clientGeom->height)
+            configVals[1] = pointer->root_y - clientGeom->height + 1;
+        else
+            configVals[1] = static_cast<uint32_t>(y - clickPoint.y() - clientGeom->height / 2);
     }
     xcb_configure_window(c, m_containerWid, XCB_CONFIG_WINDOW_X | XCB_CONFIG_WINDOW_Y, configVals);
 
@@ -610,9 +634,11 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         event->detail = mouseButton;
 
         xcb_send_event(c, false, m_windowId, XCB_EVENT_MASK_BUTTON_PRESS, (char *) event);
+        qInfo()<<"xEmbedToSNI::Forward button press events through the xcb_send_event";
         delete event;
     } else {
-//        sendXTestPressed(QX11Info::display(), mouseButton);
+        sendXTestPressed(QX11Info::display(), mouseButton);
+        qInfo()<<"xEmbedToSNI::Forward button press events through the sendXTestPressed";
     }
 
     //mouse up
@@ -634,9 +660,11 @@ void SNIProxy::sendClick(uint8_t mouseButton, int x, int y)
         event->detail = mouseButton;
 
         xcb_send_event(c, false, m_windowId, XCB_EVENT_MASK_BUTTON_RELEASE, (char *) event);
+        qInfo()<<"xEmbedToSNI::Forward button release events through the xcb_send_event";
         delete event;
     } else {
-//        sendXTestReleased(QX11Info::display(), mouseButton);
+        sendXTestReleased(QX11Info::display(), mouseButton);
+        qInfo()<<"xEmbedToSNI::Forward button release events through the sendXTestReleased";
     }
 
 #ifndef VISUAL_DEBUG
